@@ -254,12 +254,18 @@ class GenerateFencingParametersAction(base.TripleOAction):
                 mac_addr = node["mac"][0]
                 node_data["host_mac"] = mac_addr
 
+                # If the MAC isn't in the hostmap, this node hasn't been
+                # provisioned, so no fencing parameters are necessary
+                if mac_addr not in hostmap:
+                    continue
+
             # Build up fencing parameters based on which Ironic driver this
             # node is using
             if node["pm_type"] == "pxe_ssh":
                 # Ironic fencing driver
                 node_data["agent"] = "fence_ironic"
-                params["action"] = self.fence_action
+                if self.fence_action:
+                    params["action"] = self.fence_action
                 params["auth_url"] = self.os_auth["auth_url"]
                 params["login"] = self.os_auth["login"]
                 params["passwd"] = self.os_auth["passwd"]
@@ -272,7 +278,8 @@ class GenerateFencingParametersAction(base.TripleOAction):
             elif node["pm_type"].split('_')[1] in ("ipmitool", "ilo", "drac"):
                 # IPMI fencing driver
                 node_data["agent"] = "fence_ipmilan"
-                params["action"] = self.fence_action
+                if self.fence_action:
+                    params["action"] = self.fence_action
                 params["ipaddr"] = node["pm_addr"]
                 params["passwd"] = node["pm_password"]
                 params["login"] = node["pm_user"]
