@@ -40,3 +40,5 @@ class OvercloudRcTest(base.TestCase):
         self.assertIn("OS_PASSWORD=AdminPassword", result['overcloudrc.v3'])
         self.assertNotIn("OS_IDENTITY_API_VERSION=3", result['overcloudrc'])
         self.assertIn("OS_IDENTITY_API_VERSION=3", result['overcloudrc.v3'])
+        self.assertIn("OS_AUTH_TYPE=password", result['overcloudrc'])
+        self.assertIn("OS_AUTH_TYPE=password", result['overcloudrc.v3'])
