@@ -15,6 +15,7 @@
 import base64
 import logging
 import os
+import paramiko
 import struct
 import time
 import uuid
@@ -42,7 +43,6 @@ def generate_passwords(mistralclient=None, stack_env=None):
     passwords = {}
 
     for name in constants.PASSWORD_PARAMETER_NAMES:
-
         # Support users upgrading from Mitaka or otherwise creating a plan for
         # a Heat stack that already exists.
         if stack_env and name in stack_env.get('parameter_defaults', {}):
@@ -68,6 +68,8 @@ def generate_passwords(mistralclient=None, stack_env=None):
         elif name in ('KeystoneCredential0', 'KeystoneCredential1',
                       'KeystoneFernetKey0', 'KeystoneFernetKey1'):
             passwords[name] = create_keystone_credential()
+        elif name == 'MigrationSshKey':
+            passwords[name] = create_ssh_keypair()
         else:
             passwords[name] = passutils.generate_password(
                 size=_MIN_PASSWORD_SIZE)
@@ -93,3 +95,18 @@ def get_snmpd_readonly_user_password(mistralclient):
 
 def create_keystone_credential():
     return base64.urlsafe_b64encode(os.urandom(32))
+
+
+def create_ssh_keypair(comment=None, bits=2048):
+    """Generate an ssh keypair for use on the overcloud"""
+    if comment is None:
+        comment = "Generated by TripleO"
+    key = paramiko.RSAKey.generate(bits)
+    keyout = six.StringIO()
+    key.write_private_key(keyout)
+    private_key = keyout.getvalue()
+    public_key = '{} {} {}'.format(key.get_name(), key.get_base64(), comment)
+    return {
+        'private_key': private_key,
+        'public_key': public_key,
+    }
